@@ -20,21 +20,20 @@
  * 
  */
 /**
-    File Name:          15.8.1.7-1.js
-    ECMA Section:       15.8.1.7.js
+    File Name:          15.8.1.8-2.js
+    ECMA Section:       15.8.1.8.js
     Description:        All value properties of the Math object should have
                         the attributes [DontEnum, DontDelete, ReadOnly]
 
-                        this test checks the ReadOnly attribute of Math.SQRT1_2
+                        this test checks the DontDelete attribute of Math.SQRT2
 
     Author:             christine@netscape.com
     Date:               16 september 1997
 */
-
-    var SECTION = "15.8.1.7-1";
+    var SECTION = "15.8.1.8-2";
     var VERSION = "ECMA_1";
     startTest();
-    var TITLE   = "Math.SQRT1_2";
+    var TITLE   = "Math.SQRT2";
 
     writeHeaderToLog( SECTION + " "+ TITLE);
 
@@ -44,7 +43,8 @@
 function getTestCases() {
     var array = new Array();
     var item = 0;
-    array[item++] = new TestCase( SECTION, "Math.SQRT1_2=0; Math.SQRT1_2", 0.7071067811865476, "Math.SQRT1_2=0; Math.SQRT1_2" );
+    array[item++] = new TestCase( SECTION, "delete Math.SQRT2; Math.SQRT2", 1.4142135623730951,     "delete Math.SQRT2; Math.SQRT2" );
+    array[item++] = new TestCase( SECTION, "delete Math.SQRT2",             false,                  "delete Math.SQRT2" );
     return ( array );
 }
 function test() {
@@ -61,4 +61,3 @@ function test() {
     stopTest();
     return ( testcases );
 }
-
